#include "symfonieqmenu.h"

SymfonieQMenu::SymfonieQMenu():
        deleteFilePath(QString())
{
}


void SymfonieQMenu::setDeleteFilePath(QString path){
    this->deleteFilePath = path;
}
